/* -----------------------------------------------------------------
 * (c) Teradyne, Inc, 2007
 * All Rights Reserved
 * Inclusion of a copyright notice does not imply that this software
 * has been published.  This software is the trade secret information
 * of Teradyne, Inc.  Use of this software is only in accordance with
 * the terms of a license agreement from Teradyne, Inc.
 * -------------------------------------------------------------------
 */
/*-------------------------------------------------------------------
 * This class is an encapsulation of the global settings for a panel of the editor
 * ------------------------------------------------------------------
 */

/*
 **************************************************************************************************
 *   Revision history:
 *   Author          Date        Description of change
 *   =============================================================================================
 *   Andy Kittross   16-Oct-2007    Made a separate class for each panel.
 **************************************************************************************************/


using System;
using System.Collections.Generic;
using System.Text;
using Teradyne.Igxl.PSetSignalsEditor;

namespace Teradyne.Igxl.PSetSignalsEditor
{
    /// <summary>
    /// This is a class which determines the currently set type
    /// </summary>
    /// 
    public class GlobalSettings
    {
        public  PanelSettings MainPanel = new PanelSettings(false);
        public  PanelSettings ComparePanel = new PanelSettings(true);
    }

    public class PanelSettings
    {
        private GlobalUtils.NspcpType mode;
        private GlobalUtils.DATA_SOURCE source;
        private bool ReadOnlyPanel;
        public PanelSettings(bool IsReadOnly)
        {
            mode = GlobalUtils.NspcpType.pset;
            // Default to driver mode in case we're launched while program is running.  
            // This will be forced to Sheet in HandleSiteActivation() if the program's not running.
            source = GlobalUtils.DATA_SOURCE.DRIVER;    
            ReadOnlyPanel = IsReadOnly;
        }

        /// <summary>
        /// Currently selected nspcp type in window
        /// </summary>
        public GlobalUtils.NspcpType NSPCP_MODE
        {
            get { return mode; }
            set { mode = value; }
        }

        /// <summary>
        /// Data source for the nspcp defintion, can be PSets/Signals
        /// </summary>
        public GlobalUtils.DATA_SOURCE DATA_SOURCE
        {
            get { return source; }
            set { source = value; }
        }

        /// <summary>
        /// DIndicates if panel is a read only.
        /// </summary>
        public bool READONLY
        {
            get { return ReadOnlyPanel; }
            set { ReadOnlyPanel = value; }
        }
    }
}
