/* -----------------------------------------------------------------
 * (c) Teradyne, Inc, 2007
 * All Rights Reserved
 * Inclusion of a copyright notice does not imply that this software
 * has been published.  This software is the trade secret information
 * of Teradyne, Inc.  Use of this software is only in accordance with
 * the terms of a license agreement from Teradyne, Inc.
 * -------------------------------------------------------------------
 */
/*-------------------------------------------------------------------
 * SheetEngine.cs file acts as an interface From which SignalSheetEngine
 * and PSetSheetEngine have been derived. 
 * ------------------------------------------------------------------
 */

/*
 ***************************************************************************************
 *   Revision history:
 *   Author          Date        Description of change
 *   =================================================================
 *   Kiran Kumar Ch 08/16/07    Addressed Review comments
 *   Kiran Kumar Ch 08/01/07    Created
 ***************************************************************************************
 */

using System;
using System.Collections;
using System.Collections.Generic;
using System.Text;
using Teradyne.Igxl.PSetSignalsEditor;
using Teradyne.Igxl.PSetSignalsEditor.PSetSignalsEditorServices;
using DMGRSIGNALSSHEETLIB;
using DMGRPSETSSHEETLIB;

namespace Teradyne.Igxl.PSetSignalsEditor
{
    /// <summary>
    /// This interface represents all methods and data structures that are responsible for 
    /// retrieving and updating Sheet (PSet/Signal) related data.
    /// </summary>
    public interface ISheetEngine
    {
        /// <summary>
        /// This method receives the nspcp object and updates the PSet/Signal Sheet (depending
        /// upon whether the engine is initialized as a PSet or a Signal Sheet Engine)
        /// </summary>
        /// <param name="obj">The pset/signal object from which the information is extracted to update
        /// the sheet.</param>
        void UpdateSheet(NspcpItem nspcpItemObj);

        /// <summary>
        /// This method reads the definition of the PSet/Signal from the PSet/Signal Sheet and populates
        /// the nspcp object with that definition. 
        /// </summary>
        /// <param name="pinName">pin name for which we want to read definition</param>
        /// <param name="instrName">Instrument name of which we want to read definition</param>
        /// <param name="nspcpName">Pset/Signal name of which we want to read definition from sheet</param>
        /// <returns>NspcpItem Object: This contains the Pset/Signal's definiton if the conditions 
        /// have been satisfied. Otherwise it contains null. </returns>
        NspcpItem ReadSheet(String pinName, String instrName, String nspcpName);

        /// <summary>
        /// Givem the parameters, this method finds a list of matching signals or psets
        /// </summary>
        /// <param name="pinName">Pin name for which a signal / pset is to be found</param>
        /// <param name="instrName">Logical instrument name for which the signal / pset is to be found</param>
        /// <returns></returns>
        String[] GetList(String pinName, String instrName);
    }
}
