/* -----------------------------------------------------------------
 * (c) Teradyne, Inc, 2007
 * All Rights Reserved
 * Inclusion of a copyright notice does not imply that this software
 * has been published.  This software is the trade secret information
 * of Teradyne, Inc.  Use of this software is only in accordance with
 * the terms of a license agreement from Teradyne, Inc.
 * -------------------------------------------------------------------
 */
/*-------------------------------------------------------------------
 * frmAddNewNspcp.cs file acts as an GUI interface through which
 * we can create new nspcp definition template.
 * ------------------------------------------------------------------
 */
/*
* *************************************************************************************************
*   Revision history:
*   Author          Date        Description of change
*   =============================================================================================
*   Shoban Jayaraj 01/18/08    tersw00116304 - Resume from add / duplicate NSPCP on error capability
*   Shoban Jayaraj 01/17/08     tersw00116199 & tersw00116204 - capitilization and punctuation corrections
*   Kiran          11/22/07     Fixed :tersw00114453
****************************************************************************************************
*/
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace Teradyne.Igxl.PSetSignalsEditor
{
    public partial class frmAddNewNspcp : Form
    {

        GlobalUtils.NspcpType m_NSPCPtype;
        String m_NSPCPName;
        bool m_bOkClicked;

        public frmAddNewNspcp(GlobalUtils.NspcpType nspcpType)
        {
            InitializeComponent();
            if (nspcpType == GlobalUtils.NspcpType.pset)
            {
                this.Text = "Add New PSet";
            }
            else
            {
                this.Text = "Add New Signal";
            }

            m_NSPCPName = "";
            m_NSPCPtype = nspcpType;
            m_bOkClicked = false;
        }

        public String NSPCP_NAME
        {
            get { return m_NSPCPName; }
        }          

        /// <summary>
        /// Close the current form.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnCancel_Click(object sender, EventArgs e)
        {
            this.Close();
        }

       

        private void frmAddNewNspcp_Load(object sender, EventArgs e)
        {
            btnOK.Enabled = false;
            
        }

        private void txtNewNspcp_TextChanged(object sender, EventArgs e)
        {
            if (!txtNewNspcp.Text.Trim().Equals(""))
                btnOK.Enabled = true;
            else
                btnOK.Enabled = false;
            txtNewNspcp.Focus();
        }

        private void btnOK_Click(object sender, EventArgs e)
        {
            m_bOkClicked = true; // we handle validation in formclosing
        }

        // 
        /// <summary>
        /// check if name is legal. Should conform to [a-z][a-z0-9_]*
        /// </summary>
        /// 
        /// Note: It is up to the caller to do advanced validation, like duplicate names, 
        /// driver validation etc
        /// 
        /// <param name="NSPCPName"></param>
        /// <returns></returns>
        private bool LegalName(String NSPCPName)
        {
            if (NSPCPName.Length == 0)
                return false;
            if (!System.Char.IsLetter(NSPCPName[0]))
                return false;
            for (int i = 1; i < NSPCPName.Length; i++)
            {
                if (!System.Char.IsLetter(NSPCPName[i]) && !System.Char.IsDigit(NSPCPName[i]) && NSPCPName[i] != '_')
                    return false;
            }
            return true;
        }

        private void frmAddNewNspcp_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (m_bOkClicked && !LegalName(txtNewNspcp.Text))
            {
                MessageBox.Show(String.Format("{0} name \"{1}\" is illegal. Name should start with a letter and contain alphanumeric characters and underscores only.", m_NSPCPtype == GlobalUtils.NspcpType.pset ? "PSet" : "Signal", txtNewNspcp.Text),
                    this.Text, MessageBoxButtons.OK, MessageBoxIcon.Information);
                
                txtNewNspcp.SelectAll();
                txtNewNspcp.Focus();

                m_bOkClicked = false; // reset
                e.Cancel = true;
                return;
            }

            m_NSPCPName = txtNewNspcp.Text;
        }
}}