// ------------------------------------------------------------------
// (c) Teradyne, Inc, 2006
//     All Rights Reserved
// Inclusion of a copyright notice does not imply that this software
// has been published.  This software is the trade secret information
// of Teradyne, Inc.  Use of this software is only in accordance with
// the terms of a license agreement from Teradyne, Inc.
// ------------------------------------------------------------------
// frmApply.cs - Allows users to choose a PSet / Signal from a list
// *************************************************************************************/
//   Revision history:
//   Author         Date        Description of change
//   =================================================================
//   shoban         2/14/2008   tersw00117400 - Added & to label for keyboard access
// *************************************************************************************/

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace Teradyne.Igxl.PSetSignalsEditor
{
    public partial class frmApply : Form
    {
        private List<string> m_nspcplist;   //List of NSPCP names.
        private GlobalSettings settings;
        public frmApply()
        {
            InitializeComponent();
        }

        //Returns the selected item
        public String NSPCP_NAME
        {
            get { return (String)lstNspcpList.SelectedItem; }
        } 

        public frmApply(ref Dictionary<String,NspcpItem> nspcplist, GlobalSettings gs)      
        {
            InitializeComponent();

            settings = gs;

            if (nspcplist != null)
            {
                m_nspcplist = new List<string>();

                foreach (String name in nspcplist.Keys)
                {
                    m_nspcplist.Add(name);
                }
            }
            else
            {
                throw new NullReferenceException("The list of PSets/Signals passed was null");
            }
        }

        /// <summary>
        /// When the form loads, the list box will contain all the nspcp's that are 
        /// currently loaded in the parameter grid.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void frmApply_Load(object sender, EventArgs e)
        {
            if (settings.MainPanel.NSPCP_MODE == GlobalUtils.NspcpType.pset)
            {
                lblSelectNspcp.Text = "Please &select the PSet to Apply.";
            }
            else
            {
                lblSelectNspcp.Text = "Please &select the Signal to Load.";
            }

            if(m_nspcplist!= null) 
            {
                lstNspcpList.DataSource = m_nspcplist;
            }
        }

        /// <summary>
        /// This is used to make the selection of the NSPCP selected
        /// to be applied.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnOK_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void lstNspcpList_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (lstNspcpList.SelectedItems.Count > 0)
            {
                btnOK.Enabled = true;
            }
            else
            {
                btnOK.Enabled = false;
            }
        }

        private void btnCancel_Click(object sender, EventArgs e)
        {
            this.Close();
        }




    }
}